@@ -61,10 +61,20 @@ sub child {
    }
 }
 
+sub idle {
+   my ($class, %arg) = @_;
+
+   EV::idle $arg{cb}
+}
+
 sub one_event {
    EV::loop EV::LOOP_ONESHOT;
 }
 
+sub loop {
+   EV::loop;
+}
+
 1;
 
 =head1 SEE ALSO
